@@ -1,7 +1,7 @@
 """
 Type annotations for memorydb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/literals/)
 
 Usage::
 
@@ -157,6 +157,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
